---
header-includes:
  - \usepackage[T1]{fontenc}
  - \usepackage[french]{babel}
  - \usepackage{datetime}
  - \usepackage{hyperref}
---

# Semaine 6: La gestion de l'incertain dans les systèmes à base de connaissances

## Systèmes à base de règles:

Référence: [Managing Uncertainty in Rule-Based Systems](http://mercury.webster.edu/aleshunas/CSIS%205420/CSIS%205420/Instructor%20Materials/Chapter%2013.pdf)

Types d'incertitude:
- Définition de l'antécédent de la règle
- Niveau de confiance en la règle
- Comment combiner les informations incertaines et le déclenchement de plusieurs règles

Méthodes pour gérer l'incertitude:
- Basées sur les probabilités
    - Objeectives
        - Valeurs bien définies pour un problème donné 
        - Jeux de hasard
    - Expérimentales
        - Obtenues par échantillonnage
        - Développer des tables de probabilités pour les assurances
    - Subjectives
        - Basées sur une opinion d'un expert
- Basées sur des heuristiques
    - Approche préférée pour les systèmes à base de règles
    - Nature inexacte des données
    - Facteurs de certitudes: développés en premier pour MYCIN
    - Logique floue: Zadeh (1965) - mots avec une signification ambigue

### Systèmes à base de règles floues

Une règle est formée de variables linguistiques et de valeurs linguistiques. Les valeurs linguistiques sont associées à un ensemble flou. Un ensemble flou est caractérisé par une fonction d'appartenance prenant une valeur entre 0 et 1 pour chacune des valeurs numériques de la variable. Un ensemble flou peut aussi être discret.

- Pour les nouvelles valeurs de la variable qui ne sont pas définies dans l'ensemble discret:
    - Interpolation
    - Réseaux de neurones

Inférence en quatre étapes:

- Calcul des degrés d'appartenance
- Inférence par les règles:
    - Union: Degré d'appartenance maximum pour toutes les conditions
    - Intersection: Degré d'appartenance minimum pour toutes les conditions
    - Couper la fonction d'appartenance à la hauteur spécifiée par la ondition de l'antécédent.
- Composition des règles
- Convertir l'ensemble flou en degrés de confiance
    - Prendre la valeur maximum des règles
    - Calculer le centre de gravité

### Approche probabiliste

Théorème de Bayes:
$$P(H\mid E)={\frac {P(E\mid H)\,P(H)}{P(E\mid H)P(H)+P(E\mid \neg H)P(\neg H)}}\cdot$$

- Utilisé en premier dans le système expert PROSPECTOR
- Approche mathématiquement correcte
- Combinaison possible de plusieurs évidences. On peut simplifier les calculs en supposant l'hypothèse que les évidences sont conditionnellement indépendantes

#### Ratios de vraisemblance

- Vraisemblance de la suffisance (tend vers 1 signifie que E est suffisant pour affirmer H): $LS=\frac{P(E \mid H)}{P(E\mid\neg N)}$
- Vraisemblance de la nécessité (tend vers 0 signifie que E est nécessaire pour affirmer H):
$LN=\frac{P(\neg E \mid H)}{P(\neg E\mid\neg N)}$

On peut utiliser ces ratios et le théorème de Bayes pour exprimer les deux règles suivantes:
$$P(H\mid E) = \frac{LS \times O(H)}{1+LS \times O(H)}$$
$$P(H\mid\neg E) = \frac{LN \times O(H)}{1+LN \times O(H)}$$
où 
$$O(H) = \frac{P(H)}{P(\neg H)}$$

Pour utiliser dans un système à base de règles, on doit fixer une valeur de LN et de LS pour chaque évidence.

#### Enjeux

Problème de MYCIN: les experts n'étaient pas capables de faire sommer $P(H \mid E) + P(\neg H \mid E) = 1$

Hypothèses: Probabilités à priori, indépendance conditionnelle (approche forte ou naïve).

Besoin de beaucoup de données pour avoir un bon estimé des probabilité conditionnelles. Était un enjeu à l'époque, probablement moins aujourd'hui ce qui ramène les bases probabilistes à l'avant-plan et le machine learning avec des approches bayesiennes (Naive Bayes).

## Systèmes à base de schémas probabilistes

Source: [Probabilistic frame-based systems](http://ai.stanford.edu/%7Ekoller/Papers/Koller+Pfeffer:AAAI98.pdf)


## Systèmes à base d'estimation (valuation-based system)

Source: [Prakash P. Shenoy - Valuation-Based Systems (Slides)](http://www.gipsa-lab.fr/summerschool/bfta/includes/Valuation-Based-Systems-Shenoy.pdf)

### Bases

Système mathématique formel pour représenter et raisonner avec des connaissances.
Deux parties:
- Statique: Représentation des connaissances
    - Variables: ensemble fini $\Phi = \lbrace X, Y, Z, \ldots \rbrace$ et sous-ensembles $r,s,t,\ldots$
    - Estimations: ensemble fini $\Psi = \lbrace \rho, \sigma\, \tau \rbrace$ qui encodent les connaîssance s sur un sous-ensemble de variable.
- Dynamique: Raisonnement avec les connaissances avec des opérateurs
    - Combinaison: $\oplus: \Psi \times \Psi \rightarrow \Psi$
    - Margiinalisation: $-X: \Psi \rightarrow \Psi$ permet de sortir X du domaine d'une estimation

Représentation graphique: réseau d'estimations

Abstraction de plusieurs calculs d'incertitude:
- Calcul propositionnel
-  Théorie des probabilités
- Théorie des fonctions de croyances: application au problème du Capitaine dans les slides
- Calcul de croyances épistémique de Spohn
- Théorie des possiibilités

Problème du capitaine: Estimer le nombre de jours de retard de son bateau à destination. Plusieurs facteurs d'incertitude.

Combinaison: [Règle de Dempster](https://wikimonde.com/article/Th%C3%A9orie_de_Dempster-Shafer)





